==> ideaIC-173.4301.1-sources.jar: org/jetbrains/plugins/gradle/model/data/CompositeBuildData.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.gradle.model.data;

import com.intellij.openapi.externalSystem.model.Key;
import com.intellij.openapi.externalSystem.model.ProjectKeys;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * @author Vladislav.Soroka
 * @since 2/17/2017
 */
public class CompositeBuildData {

  @NotNull
  public static final Key<CompositeBuildData> KEY = Key.create(CompositeBuildData.class, ProjectKeys.PROJECT.getProcessingWeight() + 1);

  private final String myRootProjectPath;
  @NotNull private List<BuildParticipant> myCompositeParticipants = ContainerUtil.newArrayList();

  public CompositeBuildData(String rootProjectPath) {
    myRootProjectPath = rootProjectPath;
  }

  public String getRootProjectPath() {
    return myRootProjectPath;
  }

  @NotNull
  public List<BuildParticipant> getCompositeParticipants() {
    return myCompositeParticipants;
  }
}

==> ideaIC-173.4548.10-sources.jar: org/jetbrains/plugins/gradle/model/data/CompositeBuildData.java <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.plugins.gradle.model.data;

import com.intellij.openapi.externalSystem.model.Key;
import com.intellij.openapi.externalSystem.model.ProjectKeys;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.NotNull;

import java.io.Serializable;
import java.util.List;

/**
 * @author Vladislav.Soroka
 * @since 2/17/2017
 */
public class CompositeBuildData implements Serializable {

  @NotNull
  public static final Key<CompositeBuildData> KEY = Key.create(CompositeBuildData.class, ProjectKeys.PROJECT.getProcessingWeight() + 1);

  private final String myRootProjectPath;
  @NotNull private List<BuildParticipant> myCompositeParticipants = ContainerUtil.newArrayList();

  public CompositeBuildData(String rootProjectPath) {
    myRootProjectPath = rootProjectPath;
  }

  public String getRootProjectPath() {
    return myRootProjectPath;
  }

  @NotNull
  public List<BuildParticipant> getCompositeParticipants() {
    return myCompositeParticipants;
  }
}
